==> Demo_CH32F103C8T6_ST7789V2_8-Bit_Parallel-Port.zip: Demo_CH32F103C8T6_ST7789V2_8-Bit_Parallel-Port/USER/main.c <==
/**********************************************************************
 * ֻѧϰʹãδɣκ;
 * ӲƬCH32F103C8T6,Ƶ72MHZ
 * ˵ST7789V 8λڳ
 
 ----------------------------------------------------
 |ǧһʾƼ޹˾                        |
 |˾վ:www.qytft.com                            |
 |Ավhttps://shop580133616.taobao.com        |
 |̻() :+86 0755-27908130                     |
 |ҵѯ:18823372746 (쾭 WXͬ)              |
 |ҵѯ:15989313508 (뾭 WXͬ)              |
 ----------------------------------------------------

 ----------------------------------------------------
 |˾ṩ֧֣κμ⻶ӭʱѧϰ    |
 |֧QQ:3597321058                             |
 |֧:qyxskj@126.com                       |
 |֧:13723763193ܹ WXͬţ               |
 |QQȺ:792027219                            |
 ----------------------------------------------------

 * ˵:
 ========================ԴŽ=======================================================        
 |   LCDģ           Ƭ                                                          |
 |     VCC      --->      3.3V      //Դ                                                 |
 |     GND      --->      GND       //Դ                                               |  
 |====================ƼŽ===================================================|
 |   LCDģ 			     Ƭ                                                          |
 |     CS       --->      PA4       //ҺƬѡźţ͵ƽЧ                     |
 |     RST      --->      PA1       //Һλźţ͵ƽЧ                     |
 |     RS       --->      PA5       //Һ/ݿźţ͵ƽߵƽݣ|
 |     WR       --->      PA10      //Һдź                                     |
 |     RD       --->      PA9       //Һź                                     |
 |     DB0~7    --->      PB0~PB7   //Һ8λź                                  |
 |     LED      --->      PA15      //Һźţ粻ƣ3.3V             |
 ===========================================================================================
 
 * :2020/5/13
 * 汾V1.0
 * ȨУؾ
 * Copyright(C) ǧһʾƼ޹˾ 2020-2035
 * All rights reserved
**********************************************************************/		
#include "debug.h"
#include "lcd.h"
#include "test.h"
int main(void)
{	
	NVIC_PriorityGroupConfig(NVIC_PriorityGroup_2);
  Delay_Init();
	LCD_Init();  //ʼҺ
	while(1)
	{
		main_test(); 		//
		Test_Read();     //IDɫֵ
		Test_Color();  		//ˢ
		Test_FillRec();		//GUIλͼ
		Test_Circle(); 		//GUIԲ
		Test_Triangle();    //GUIλͼ
		English_Font_test();//Ӣʾ
		Chinese_Font_test();//ʾ
		Pic_test();			//ͼƬʾʾ
		Rotate_Test();   //תʾ		
	}
}

==> Demo_CH32F103C8T6_ST7789V2_16-Bit_Parallel-Port.zip: Demo_CH32F103C8T6_ST7789V2_16-Bit_Parallel-Port/USER/main.c <==
/**********************************************************************
 * ֻѧϰʹãδɣκ;
 * ӲƬCH32F103C8T6,Ƶ72MHZ
 * ˵ST7789V 16λڳ
 
 ----------------------------------------------------
 |ǧһʾƼ޹˾                        |
 |˾վ:www.qytft.com                            |
 |Ավhttps://shop580133616.taobao.com        |
 |̻() :+86 0755-27908130                     |
 |ҵѯ:18823372746 (쾭 WXͬ)              |
 |ҵѯ:15989313508 (뾭 WXͬ)              |
 ----------------------------------------------------

 ----------------------------------------------------
 |˾ṩ֧֣κμ⻶ӭʱѧϰ    |
 |֧QQ:3597321058                             |
 |֧:qyxskj@126.com                       |
 |֧:13723763193ܹ WXͬţ               |
 |QQȺ:792027219                            |
 ----------------------------------------------------

 * ˵:
 ========================ԴŽ=======================================================        
 |   LCDģ           Ƭ                                                          |
 |     VCC      --->      3.3V      //Դ                                                 |
 |     GND      --->      GND       //Դ                                               |  
 |====================ƼŽ===================================================|
 |   LCDģ 			     Ƭ                                                          |
 |     CS       --->      PA4       //ҺƬѡźţ͵ƽЧ                     |
 |     RST      --->      PA1       //Һλźţ͵ƽЧ                     |
 |     RS       --->      PA5       //Һ/ݿźţ͵ƽߵƽݣ|
 |     WR       --->      PA10      //Һдź                                     |
 |     RD       --->      PA9       //Һź                                     |
 |     DB0~15   --->      PB0~PB15  //Һ16λź                               |
 |     LED      --->      PA15      //Һźţ粻ƣ3.3V             |
 |=============================================================================|
 |	 LCDģ 			     Ƭ                                                          |
 |     T_IRQ    --->      PA12      //жź                                   |
 |     T_DO     --->      PA2       //SPI߶ź                                  |
 |     T_DIN    --->      PA3       //SPIдź                                  |
 |     T_CS     --->      PA11      //Ƭѡź                                   |
 |     T_CLK    --->      PA8       //SPIʱź                                |
 ===========================================================================================
 
 * :2020/5/13
 * 汾V1.0
 * ȨУؾ
 * Copyright(C) ǧһʾƼ޹˾ 2020-2035
 * All rights reserved
**********************************************************************/		
#include "debug.h"
#include "lcd.h"
#include "test.h"
int main(void)
{	
	NVIC_PriorityGroupConfig(NVIC_PriorityGroup_2);
  Delay_Init();
	LCD_Init();  //ʼҺ
	while(1)
	{
		main_test(); 		//
		Test_Read();     //IDɫֵ
		Test_Color();  		//ˢ
		Test_FillRec();		//GUIλͼ
		Test_Circle(); 		//GUIԲ
		Test_Triangle();    //GUIλͼ
		English_Font_test();//Ӣʾ
		Chinese_Font_test();//ʾ
		Pic_test();			//ͼƬʾʾ
		Rotate_Test();   //תʾ
		//߲Ҫܣע͵津
		Touch_Test();		//д		
	}
}
